@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,13 +12,7 @@
 #ifndef ADDOPTIONDIALOG_H
 #define ADDOPTIONDIALOG_H
 
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-
-/**
-  *@author Pascal Brachet
-  */
+#include "ui_addoptiondialog.h"
 
 class AddOptionDialog : public QDialog
 {
@@ -26,10 +20,7 @@ class AddOptionDialog : public QDialog
 public: 
 	AddOptionDialog(QWidget *parent = 0, const char *name = 0);
 	~AddOptionDialog();
-   QLineEdit *lineEdit;
-private:
-	  QPushButton *buttonOk;
-	  QPushButton *buttonCancel;
+	Ui::AddOptionDialog ui;
 };
 
 #endif
