@@ -15,15 +15,18 @@
 #include <QMainWindow>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QtWebKit>
+//#include <QtWebKit>
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+#include "QtWebKitWidgets/qwebview.h"
+#else
 #include <QWebView>
-
+#endif
 
 class Browser : public QMainWindow
 {
     Q_OBJECT
 public:
-    Browser( const QString home, bool showToolBar=true, QWidget* parent = 0, Qt::WFlags flags = 0);
+    Browser( const QString home, bool showToolBar=true, QWidget* parent = 0);
     ~Browser();
 
 protected slots:
