@@ -22,7 +22,7 @@ FindWidget::FindWidget(QWidget* parent)
 ui.setupUi(this);
 connect(ui.findButton, SIGNAL( clicked() ), this, SLOT( doFind() ) );
 connect(ui.closeButton, SIGNAL( clicked() ), this, SLOT( doHide() ) );
-ui.findButton->setShortcut(Qt::Key_Return);
+//ui.findButton->setShortcut(Qt::Key_Return);
 ui.findButton->setToolTip("Return");
 ui.closeButton->setShortcut(Qt::Key_Escape);
 ui.closeButton->setToolTip("Escape");
@@ -146,3 +146,7 @@ else
   }
 }
 
+void FindWidget::keyPressEvent ( QKeyEvent * e ) 
+{
+if ((e->key()==Qt::Key_Enter)||(e->key()==Qt::Key_Return)) doFind();
+}
