@@ -12,6 +12,10 @@
 #include <QtGui>
 #include <QAbstractItemModel>
 #include <QPainter>
+#include <QApplication>
+#include <QPixmap>
+#include <QByteArray>
+#include <QDebug>
 #include "icondelegate.h"
 
 static const int textMargin = 2;
@@ -43,7 +47,8 @@ void IconDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     // do layout
     value = model->data(index, Qt::DecorationRole);
     QPixmap pixmap = decoration(opt, value);
-    QRect pixmapRect = pixmap.rect();
+    QRect pixmapRect(0,0,32,32);//=pixmap.rect();
+    
 
     QFontMetrics fontMetrics(opt.font);
     QString text = model->data(index, Qt::DisplayRole).toString();
@@ -71,6 +76,7 @@ painter->fillRect(option.rect,QColor("#cdd2d8"));
 
     // draw the item
 //    drawCheck(painter, opt, checkRect, checkState);
+
     drawDecoration(painter, opt, pixmapRect, pixmap);
 //    drawDisplay(painter, opt, textRect, text);
 //    drawFocus(painter, opt, textRect);
@@ -109,13 +115,30 @@ QSize IconDelegate::sizeHint(const QStyleOptionViewItem &option,
 void IconDelegate::drawDecoration(QPainter *painter, const QStyleOptionViewItem &option,
                                    const QRect &rect, const QPixmap &pixmap) const
 {
+    QPoint p=rect.topLeft();
+    
     if (!pixmap.isNull() && !rect.isEmpty()) {
         if (option.state & QStyle::State_Selected) {
             bool enabled = option.state & QStyle::State_Enabled;
             QPixmap *pm = selected(pixmap, option.palette, enabled);
-            painter->drawPixmap(rect.topLeft(), *pm);
+	    #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+            if (qApp->devicePixelRatio()==2)
+            {
+	    pm->setDevicePixelRatio(qApp->devicePixelRatio());
+        p-=QPoint(16,0);
+          }      
+	    #endif
+            painter->drawPixmap(p, *pm);
         } else {
-            painter->drawPixmap(rect.topLeft(), pixmap);
+QPixmap *pm=selected(pixmap, option.palette, true);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+            if (qApp->devicePixelRatio()==2)
+            {
+                pm->setDevicePixelRatio(qApp->devicePixelRatio());
+                p-=QPoint(16,0);
+            }      
+#endif
+            painter->drawPixmap(p, *pm);
         }
     }
 }
@@ -188,6 +211,7 @@ void IconDelegate::doLayout(const QStyleOptionViewItem &option,
     QSize pm(0, 0);
     if (pixmapRect->isValid())
         pm = option.decorationSize;
+    
     if (hint) {
         w = qMax(textRect->width(), pm.width());
         h = qMax(textRect->height(), pm.height());
@@ -214,6 +238,7 @@ void IconDelegate::doLayout(const QStyleOptionViewItem &option,
         else if (position == QStyleOptionViewItem::Left)
             position = QStyleOptionViewItem::Right;
     }
+
     switch (position) {
     case QStyleOptionViewItem::Top: {
         if (!pm.isEmpty())
@@ -250,7 +275,7 @@ void IconDelegate::doLayout(const QStyleOptionViewItem &option,
         decoration = *pixmapRect;
         break;
     }
-
+    
     if (!hint) { // we only need to do the internal layout if we are going to paint
         *checkRect = QStyle::alignedRect(option.direction, Qt::AlignCenter,
                                          checkRect->size(), check);
@@ -286,10 +311,26 @@ QPixmap IconDelegate::decoration(const QStyleOptionViewItem &option, const QVari
   \internal
 */
 
+static QString qPixmapSerial(quint64 i, bool enabled)
+{
+    ushort arr[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, '-', ushort('0' + enabled) };
+    ushort *ptr = &arr[16];
+
+    while (i > 0) {
+        // hey - it's our internal representation, so use the ascii character after '9'
+        // instead of 'a' for hex
+        *(--ptr) = '0' + i % 16;
+        i >>= 4;
+    }
+
+    return QString((const QChar *)ptr, int(&arr[sizeof(arr) / sizeof(ushort)] - ptr));
+}
+
 QPixmap *IconDelegate::selected(const QPixmap &pixmap, const QPalette &palette, bool enabled) const
 {
-    QString key;
-    key.sprintf("%d-%d", pixmap.serialNumber(), enabled);
+    //QString key;
+    //key.sprintf("%d-%d", pixmap.serialNumber(), enabled);
+    QString key = qPixmapSerial(pixmap.cacheKey(), enabled);
     QPixmap *pm = QPixmapCache::find(key);
     if (!pm) {
         QImage img = pixmap.toImage().convertToFormat(QImage::Format_ARGB32_Premultiplied);
